@@ -15,18 +15,36 @@
 
 import os
 import subprocess
+import sys
 import time
 from urllib import request, error
 
-from .loader import get_loader
+from perfetto.trace_processor.platform import PlatformDelegate
+
+# Default port that trace_processor_shell runs on
+TP_PORT = 9001
 
 
-def load_shell(bin_path, unique_port, verbose):
-  shell_path = get_loader().get_shell_path(bin_path=bin_path)
-  port, url = get_loader().get_free_port(unique_port=unique_port)
-  p = subprocess.Popen([shell_path, '-D', '--http-port', port],
-                       stdout=subprocess.DEVNULL,
-                       stderr=None if verbose else subprocess.DEVNULL)
+def load_shell(bin_path: str, unique_port: bool, verbose: bool,
+               ingest_ftrace_in_raw: bool, platform_delegate: PlatformDelegate):
+  addr, port = platform_delegate.get_bind_addr(
+      port=0 if unique_port else TP_PORT)
+  url = f'{addr}:{str(port)}'
+
+  shell_path = platform_delegate.get_shell_path(bin_path=bin_path)
+  if os.name == 'nt' and not shell_path.endswith('.exe'):
+    tp_exec = [sys.executable, shell_path]
+  else:
+    tp_exec = [shell_path]
+
+  args = ['-D', '--http-port', str(port)]
+  if not ingest_ftrace_in_raw:
+    args.append('--no-ftrace-raw')
+
+  p = subprocess.Popen(
+      tp_exec + args,
+      stdout=subprocess.DEVNULL,
+      stderr=None if verbose else subprocess.DEVNULL)
 
   while True:
     try:
@@ -38,7 +56,7 @@ def load_shell(bin_path, unique_port, verbose):
         raise Exception(
             "Trace processor failed to start, please file a bug at https://goto.google.com/perfetto-bug"
         )
-      req = request.urlretrieve(f'http://{url}/status')
+      _ = request.urlretrieve(f'http://{url}/status')
       time.sleep(1)
       break
     except error.URLError:
